##  Exporting Diagrams From Lucidchart
To export diagrams from Lucidchart, follow these steps:
  1. Navigate to File > Export
  2. Select the desired file type for the export.
  3. An overlay may prompt you to share the diagram as a link instead; if not, proceed and click Download.
![Exporting Diagrams From Lucidchart](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fbac47a441014a056fe31cb0082e1_LowRes.png)
Exporting Diagrams From Lucidchart


YesNo
Send
